@@ -1,7 +1,7 @@
 package Mojo::Webqq;
 use strict;
 use Carp ();
-$Mojo::Webqq::VERSION = "2.1.8";
+$Mojo::Webqq::VERSION = "2.1.9";
 use Mojo::Webqq::Base 'Mojo::EventEmitter';
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -30,7 +30,7 @@ has send_interval       => 3;           #全局发送消息间隔时间
 has check_account       => 0;           #是否检查预设账号与实际登录账号是否匹配
 has disable_color       => ($^O eq 'MSWin32' ? 1 : 0);           #是否禁用终端打印颜色
 has ignore_send_retcode      => sub{[1202,100100]}; #对发送消息返回这些状态码不认为发送失败，不重试
-has ignore_poll_retcode      => sub{[102,109,110,1202,100012]}; #对接收消息返回这些状态码不认为接收失败，不重新登录
+has ignore_poll_retcode      => sub{[102,109,110,1202,100000,100012]}; #对接收消息返回这些状态码不认为接收失败，不重新登录
 has ignore_poll_http_code => sub{[504,502]}; #忽略接收消息请求返回的502/504状态码，因为并不影响消息接收，以免引起恐慌
 has ignore_unknown_id   => 1; #其他设备上自己发送的消息，在webqq上会以接受消息的形式再次接收到，id还未知,是否忽略掉这种消息
 has allow_message_sync => 0; #是否允许同步来自其他设备登录账号发送的消息，由于webqq自身发送消息后也会收到服务端重复的消息，且没办法和来自其他设备的消息区分，会导致出现一些不期望的结果，比如某些插件会陷入死循环等，因此默认不开启消息同步，如果你只是用来api发送消息或者irc聊天，则开启此选项，可以同步来自其他设备的消息，体验会更好一些
@@ -66,6 +66,7 @@ has is_update_group_member_ext => 0;                         #是否定期更新
 has is_update_friend        => 1;                            #是否定期更新好友信息
 has is_update_discuss       => 1;                            #是否定期更新讨论组信息
 has update_interval         => 600;                          #定期更新的时间间隔
+has update_group_min_interval => 5;                         #群组更新的最小时间间隔（防止死循环）
 
 has encrypt_method      => "perl";     #perl|js
 has tmpdir              => sub {$ENV{MOJO_WEBQQ_TMPDIR} || File::Spec->tmpdir();};
